@@ -30,10 +30,23 @@
 
 #include <LXQt/Application>
 #include <LXQt/GridLayout>
+#include <QCommandLineParser>
 
 int main(int argc, char *argv[])
 {
     LXQt::Application app(argc, argv);
+    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+
+    QCommandLineParser parser;
+    parser.setApplicationDescription(QStringLiteral("LXQt About"));
+    const QString VERINFO = QStringLiteral(LXQT_ABOUT_VERSION
+                                           "\nliblxqt   " LXQT_VERSION
+                                           "\nQt        " QT_VERSION_STR);
+    app.setApplicationVersion(VERINFO);
+    parser.addVersionOption();
+    parser.addHelpOption();
+    parser.process(app);
+
     AboutDialog dlg;
     return app.exec();
 }
